discover

package
v0.0.0-...-88afe18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: BSD-2-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

const DiscoveredTypeCommissionable = 2
const DiscoveredTypeCommissioned = 1

Variables

This section is empty.

Functions

func Discover2

func Discover2(iface string, service string, disableipv6 bool) (map[string]DiscoveredDevice, error)

func ListInterfaces

func ListInterfaces(name string) []net.Interface

Types

type DiscoveredDevice

type DiscoveredDevice struct {
	Name      string
	Host      string
	Type      DiscoveredType
	Addrs     []net.IP
	PH        string
	CM        string
	VP        string
	VendorId  int
	ProductId int
	D         string
	DN        string
}

func Discover

func Discover(iface string) ([]DiscoveredDevice, error)

func DiscoverAllComissionable deprecated

func DiscoverAllComissionable(interfac string, disableipv6 bool) []DiscoveredDevice

DiscoverAllComissionable uses mdns to discover all matter devices with open commissioning window

Deprecated: use DiscoverAllCommissionable.

func DiscoverAllComissioned deprecated

func DiscoverAllComissioned(interfac string, disableipv6 bool) []DiscoveredDevice

DiscoverAllComissioned uses mdns to discover all matter devices which are already commissioned. Name of these devices contains compressed fabric identifier and id of device in fabric.

Deprecated: use DiscoverAllCommissioned.

func DiscoverAllCommissionable

func DiscoverAllCommissionable(interfac string, disableipv6 bool) []DiscoveredDevice

DiscoverAllCommissionable uses mdns to discover all matter devices with open commissioning window

func DiscoverAllCommissioned

func DiscoverAllCommissioned(interfac string, disableipv6 bool) []DiscoveredDevice

DiscoverAllCommissioned uses mdns to discover all matter devices which are already commissioned. Name of these devices contains compressed fabric identifier and id of device in fabric.

func DiscoverComissioned deprecated

func DiscoverComissioned(interfac string, disableipv6 bool, id string) []DiscoveredDevice

DiscoverComissioned uses mdns to discover concrete already commissioned matter device. It searches for device commissioned to current fabric with identifier id.

Deprecated: use DiscoverCommissioned.

func DiscoverCommissioned

func DiscoverCommissioned(interfac string, disableipv6 bool, id string) []DiscoveredDevice

DiscoverCommissioned uses mdns to discover concrete already commissioned matter device. It searches for device commissioned to current fabric with identifier id.

func (DiscoveredDevice) Dump

func (d DiscoveredDevice) Dump()

type DiscoveredType

type DiscoveredType int

Jump to